#!/bin/sh
#BEGIN COPYRIGHT
#*************************************************************************
#
# Licensed Materials - Property of IBM
# 5725-C94, 5725-C95, 5725-C96
# (C) Copyright IBM Corporation 2005, 2016. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#
#*************************************************************************
#END COPYRIGHT
command=bootstrapProcessServerData.sh
PLATFORM=`/bin/uname`

usage()
{
  echo 
  echo "Usage: bootstrapProcessServerData.sh [-h(elp)] [-?]" 
  echo "       [-nodeName <nodeName> -serverName <serverName>]"
  echo "       [-clusterName <clusterName>]"
  echo 
  echo "Where: "
  echo "    -nodeName          - Optional node name.  Must be specified"
  echo "if -serverName argument specified for a non-cluster server part of an ND Environment."
  echo "    -serverName        - Optional server name.  Must be specified"
  echo "if -nodeName argument specified for a non-cluster server part of an ND Environment."
  echo "    -clusterName       - Optional cluster name. Must be specified for a cluster"
  echo "            			part of an ND environment."
  echo
  echo "NOTE:  The parameters are case-sensitive."
  echo
  echo "Example 1: bootstrap data into a non-cluster server part of an"
  echo "ND environment"
  echo "bootstrapProcessServerData.sh  -nodeName node01 -serverName server1"
  echo
  echo "Example 2: bootstrap data into a clusters"
  echo "bootstrapProcessServerData.sh  -clusterName myAppCluster"
  echo
  echo "Example 3: bootstrap data into a stand-alone default profile server"
  echo "bootstrapProcessServerData.sh  "
  echo
  exit $1
}

checkErrors()
{
if [ "$?" -ne "0" ]
then
  echo 
  echo "Bootstrap failed"
  echo 
  exit 1
fi
}

loadCluster()
{
  LOGFILE=${USER_INSTALL_ROOT}/logs/bootstrapProcesServerData.${CLUSTERNAME}.log
  echo 
  echo "Bootstraping data into cluster ${CLUSTERNAME} and logging into ${LOGFILE}" 
  echo
  if [ "$PLATFORM" = "SunOS" ]
    then
  	"${WAS_HOME}/bin/wsadmin.sh" -lang jython -connType none -javaoption -Xmx4096m -javaoption -XX:MaxPermSize=512m -tracefile "${LOGFILE}" -c "AdminTask.bootstrapProcessServerData(['-clusterName','${CLUSTERNAME}'])"
  	checkErrors 	
  else
  	"${WAS_HOME}/bin/wsadmin.sh" -lang jython -connType none -javaoption -Xmx4096m -tracefile "${LOGFILE}" -c "AdminTask.bootstrapProcessServerData(['-clusterName','${CLUSTERNAME}'])"
  	checkErrors
  fi  
}

doDefault()
{
  LOGFILE=${USER_INSTALL_ROOT}/logs/bootstrapProcesServerData.log
  echo 
  echo "Bootstraping data using default action and logging into ${LOGFILE}" 
  echo
  if [ "$PLATFORM" = "SunOS" ]
    then
  	"${WAS_HOME}/bin/wsadmin.sh" -lang jython -connType none -javaoption -Xmx4096m -javaoption -XX:MaxPermSize=512m -tracefile "${LOGFILE}" -c "AdminTask.bootstrapProcessServerData(['-default','${DEFAULT_ACTION}'])"
  	checkErrors 	
  else
  	"${WAS_HOME}/bin/wsadmin.sh" -lang jython -connType none -javaoption -Xmx4096m -tracefile "${LOGFILE}" -c "AdminTask.bootstrapProcessServerData(['-default','${DEFAULT_ACTION}'])"
  	checkErrors
  fi
}

loadServerND()
{
  LOGFILE=${USER_INSTALL_ROOT}/logs/bootstrapProcesServerData.${NODENAME}_${SERVERNAME}.log
  echo 
  echo "Bootstraping data into server ${SERVERNAME} on node ${NODENAME} and logging into ${LOGFILE}"    
  echo 
  if [ "$PLATFORM" = "SunOS" ]
    then
    "${WAS_HOME}/bin/wsadmin.sh" -lang jython -connType none -javaoption -Xmx4096m -javaoption -XX:MaxPermSize=512m -tracefile "${LOGFILE}" -c "AdminTask.bootstrapProcessServerData(['-nodeName','${NODENAME}','-serverName','${SERVERNAME}'])"
    checkErrors  
  else
  	"${WAS_HOME}/bin/wsadmin.sh" -lang jython -connType none -javaoption -Xmx4096m -tracefile "${LOGFILE}" -c "AdminTask.bootstrapProcessServerData(['-nodeName','${NODENAME}','-serverName','${SERVERNAME}'])"
  	checkErrors
  fi  
}

loadServer()
{
  LOGFILE=${USER_INSTALL_ROOT}/logs/bootstrapProcesServerData.log
  echo 
  echo "Bootstraping data for server at ${USER_INSTALL_ROOT} and logging into ${LOGFILE}"    
  echo
  if [ "$PLATFORM" = "SunOS" ]
    then
    "${WAS_HOME}/bin/wsadmin.sh" -lang jython -connType none -javaoption -Xmx4096m -javaoption -XX:MaxPermSize=512m -tracefile "${LOGFILE}" -c "AdminTask.bootstrapProcessServerData([])"
  	checkErrors       	
  else
  	"${WAS_HOME}/bin/wsadmin.sh" -lang jython -connType none -javaoption -Xmx4096m -tracefile "${LOGFILE}" -c "AdminTask.bootstrapProcessServerData([])"
  	checkErrors
  fi  
}

report()
{
  echo 
  echo "The bootstrapping of data completed. Check the output for errors."
  echo 
}

until [ "$#" = "0" ]

do
  case "$1" in
    '-help'|'-h'|'-?')
      usage 0
      ;;
    '-serverName')
      SERVERNAME="$2"
      shift;shift
      ;;
    '-nodeName')
      NODENAME="$2"
      shift;shift
      ;;
    '-clusterName')
      CLUSTERNAME="$2"
      shift;shift
      ;;
    '-default')
      DEFAULT_ACTION="$2"
      shift;shift
      ;;
    '-USER_INSTALL_ROOT')
      USER_INSTALL_ROOT="$2"
      shift;shift
      ;;
     *)
      ## ignore unknown params and continue
      shift
      ;; 
  esac
done

if [ ! "$USER_INSTALL_ROOT" ]
then
  echo 
  echo "USER_INSTALL_ROOT is not set.  Run command from profile/bin directory or run setupCmdLine.sh prior to this command."
  echo 
  usage
fi
if [ ! "$WAS_HOME" ]
then
  echo 
  echo "WAS_HOME is not set. Run command from profile/bin directory or run setupCmdLine.sh prior to this command."
  echo 
  exit
fi
if [ "$CLUSTERNAME" ] && [ ! "$NODENAME" ] && [ ! "$SERVERNAME" ]
  then
  loadCluster
elif [ ! "$CLUSTERNAME" ] && [ "$NODENAME" ] && [ "$SERVERNAME" ]
  then
  loadServerND
elif [ "$DEFAULT_ACTION" ]
  then
  doDefault
elif [ ! "$NODENAME" ] && [ ! "$SERVERNAME" ]
  then
  loadServer
else
  echo 
  echo "Incorrect combination of parameters specified."
  echo 
  usage 1
fi

